@@ -1,5 +1,5 @@
 /*
-  Copyright (C) 2003 - 2019 GraphicsMagick Group
+  Copyright (C) 2003 - 2025 GraphicsMagick Group
   Copyright (C) 2002 ImageMagick Studio
   Copyright 1991-1999 E. I. du Pont de Nemours and Company
 
@@ -34,12 +34,12 @@ extern "C" {
   identifying the release.
 */
 #define MagickPackageName "GraphicsMagick"
-#define MagickCopyright  "Copyright (C) 2002-2019 GraphicsMagick Group.\nAdditional copyrights and licenses apply to this software.\nSee http://www.GraphicsMagick.org/www/Copyright.html for details."
-#define MagickLibVersion  0x232000
-#define MagickLibVersionText  "1.3.32"
-#define MagickLibVersionNumber 23,20,0
-#define MagickChangeDate   "20190615"
-#define MagickReleaseDate  "2019-06-15"
+#define MagickCopyright  "Copyright (C) 2002-2025 GraphicsMagick Group.\nAdditional copyrights and licenses apply to this software.\nSee http://www.GraphicsMagick.org/www/Copyright.html for details."
+#define MagickLibVersion  0x282502
+#define MagickLibVersionText  "1.4"
+#define MagickLibVersionNumber 28,25,2
+#define MagickChangeDate   "20251018"
+#define MagickReleaseDate  "snapshot-20251018"
 
 /*
   The MagickLibInterfaceNewest and MagickLibInterfaceOldest defines
@@ -54,7 +54,7 @@ extern "C" {
   MagickLibVersionNumber, but these are broken out and simplified so
   that they can be easily used in C pre-processor logic.
 */
-#define MagickLibInterfaceNewest 23
+#define MagickLibInterfaceNewest 28
 #define MagickLibInterfaceOldest 3
 
 #if (QuantumDepth == 8)
